#import "MenuClock.h"

#define	TimeFormat		@"TimeFormat"
#define	defaultTimeFormat	@"%I:%M:%S %p %m/%d/%y"

@implementation MenuClock

+ (void)initialize{

    NSUserDefaults *defaults = [NSUserDefaults standardUserDefaults];
    NSDictionary *appDefaults = [NSDictionary dictionaryWithObject:defaultTimeFormat forKey:TimeFormat];

    [defaults registerDefaults:appDefaults];
}

- init
{
    NSRect		screenRect, windowRect;
    NSFont		*font;
    float		f;

    screenRect = [[NSScreen mainScreen] frame];

    windowRect.origin.x =  screenRect.size.width - 250;
    windowRect.origin.y = screenRect.size.height - 14;
    windowRect.size.width = 250;
    f = 14;
    windowRect.size.height = (f ? f : 14);

    window = [[[NSWindow alloc] initWithContentRect:windowRect styleMask:0 backing:NSBackingStoreBuffered defer:NO] retain];

    [window setLevel:NSModalPanelWindowLevel];
    [window orderWindow:NSWindowAbove relativeTo:0];
    [window orderFrontRegardless];

    font = [NSFont menuFontOfSize:12];

    textField = [[NSTextField alloc] initWithFrame:[window frame]];
    [textField setFont:font];
    [textField setBordered:NO];
    [textField setDrawsBackground:NO];
    [textField setEditable:NO];
    [[textField cell] setAlignment:NSRightTextAlignment];

    [textField setStringValue:[[NSCalendarDate calendarDate] descriptionWithCalendarFormat:[[NSUserDefaults standardUserDefaults] stringForKey:TimeFormat]]];

    [window setContentView:textField];

    timer = [[NSTimer scheduledTimerWithTimeInterval:1.0 target:self selector:@selector(updateTimer:) userInfo:nil repeats:YES] retain];

    [window display];

    return self;
}

- (void)updateTimer:(id)sender
{
    [textField setStringValue:[[NSCalendarDate calendarDate] descriptionWithCalendarFormat:[[NSUserDefaults standardUserDefaults] stringForKey:TimeFormat]]];
}

- (void)dealloc
{
    [timer invalidate];
    [timer release];
    [textField release];
    [window release];
    return;
}

- (void)about:(id)sender
{
    [aboutWindow center];
    [menuFormat setStringValue:[[NSUserDefaults standardUserDefaults] stringForKey:TimeFormat]];
    [menuSample setStringValue:[[NSCalendarDate calendarDate] descriptionWithCalendarFormat:[[NSUserDefaults standardUserDefaults] stringForKey:TimeFormat]]];
    [aboutWindow makeKeyAndOrderFront:self];
}

- (void)restoreDefault:(id)sender
{
    [[NSUserDefaults standardUserDefaults] setObject:defaultTimeFormat forKey:TimeFormat];
    [menuFormat setStringValue:defaultTimeFormat];
    [menuSample setStringValue:[[NSCalendarDate calendarDate] descriptionWithCalendarFormat:defaultTimeFormat]];
}
- (void)changeFormat:(id)sender
{
    NS_DURING
        [menuSample setStringValue:[[NSCalendarDate calendarDate] descriptionWithCalendarFormat:[menuFormat stringValue]]];
        [[NSUserDefaults standardUserDefaults] setObject:[menuFormat stringValue] forKey:TimeFormat];
    NS_HANDLER
        [menuSample setStringValue:@"invalid date format"];
    NS_ENDHANDLER
}


@end


@implementation ClockApp

- (void)finishLaunching
{
	NSPoint aPt = {-10000,-10000};

	[super finishLaunching]; 
	[_appIcon setFrameOrigin:aPt];
        return;
}

@end